@@ -5,6 +5,6 @@ class DjangoModelNoCommitFactory(factory.DjangoModelFactory):
     ABSTRACT_FACTORY = True
 
     @classmethod
-    def _create(cls, target_class, *args, **kwargs):
+    def _create(cls, *args, **kwargs):
         kwargs['commit_remote'] = False
-        return super(DjangoModelNoCommitFactory, cls)._create(target_class, *args, **kwargs)
+        return super(DjangoModelNoCommitFactory, cls)._create(*args, **kwargs)
