@@ -11,7 +11,7 @@ class User(VkontaktePKModel):
     '''
     Test model should be on top level, otherwise table will not be created
     '''
-    resolve_screen_name_type = 'user'
+    resolve_screen_name_types = ['user']
     screen_name = models.CharField(u'Короткое имя группы', max_length=50, unique=True)
     slug_prefix = 'id'
 
@@ -96,4 +96,4 @@ class VkontakteApiTest(TestCase):
         i = 0
         for count, total in instance.some_method(10, as_generator=True):
             self.assertEqual((count, total), (i, 10))
-            i += 1
\ No newline at end of file
+            i += 1
